<?php 

// Do not allow direct access to the file.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Agama Slider Class
 *
 * @since 1.2.9
 */
class Agama_Slider {
	
	/**
	 * Slider Initialization
	 *
	 * @since 1.2.9
	 */
	public static function init() {
		self::render();
	}
	
	/**
	 * Get Slider Options
	 *
	 * @since 1.2.9
	 */
	private static function get_options() {
		global $button, $enabled, $visibility, $particles, $slide;
		
		$enabled 	= esc_attr( get_theme_mod( 'agama_slider_enable', true ) );
		$visibility	= esc_attr( get_theme_mod( 'agama_slider_visibility', 'homepage' ) );
		$particles	= esc_attr( get_theme_mod( 'agama_slider_particles', true ) );
		
		/* Customized by Daisuke 2018.09.15 */
		for($i = 1; $i <= 10; $i++){
			$slide[(string) $i]['img']         = get_attachment_image_src(esc_url( get_theme_mod( 'agama_slider_image_'.$i, AGAMA_IMG . 'header_img.jpg' ) ), 'large');
			$slide[(string) $i]['title']       = esc_attr( get_theme_mod( 'agama_slider_title_'.$i, 'Welcome to Agama' ) );
			$slide[(string) $i]['animate']     = esc_attr( get_theme_mod( 'agama_slider_title_animation_'.$i, 'bounceInLeft' ) );
			$slide[(string) $i]['title_color'] = esc_attr( get_theme_mod( 'agama_slider_title_color_'.$i, '#fff' ) );
			$button[(string) $i]['title']      = esc_attr( get_theme_mod( 'agama_slider_button_title_'.$i, 'Learn More' ) );
			$button[(string) $i]['animate']    = esc_attr( get_theme_mod( 'agama_slider_button_animation_'.$i, 'bounceInRight' ) );
			$button[(string) $i]['url']        = esc_url( get_theme_mod( 'agama_slider_button_url_'.$i, '#' ) );
		}
	}
	
	/**
	 * Render Agama Slider
	 *
	 * @since 1.2.9
	 */
	private static function render() {
		global $button, $enabled, $visibility, $particles, $slide;
		
		self::get_options();
		
		if( $enabled && $visibility == 'homepage' && is_home() || 
			$enabled && $visibility == 'frontpage' && is_front_page() 
		) {
			echo '<div id="agama-slider-wrapper">';
				if( $particles ) {
					echo '<div id="particles-js" class="agama-particles"></div>';
				}
				echo '<div id="agama_slider" class="camera_wrap">';
					/* Customized by Daisuke 2018.09.15 */
					for($i = 1; $slide[(string) $i]['img'] && $i <= 10; $i++){
						if( $slide[(string) $i]['img'] ) {
							echo '<div data-src="'. $slide[(string) $i]['img']. '" data-alt="'. $slide[(string) $i]['title'] .'">';
								echo '<div class="slide-content slide-'.$i.'">';
									echo '<div class="slide-content-cell">';
										echo '<div class="container">';
											echo '<div class="row">';
												echo '<div class="col-md-12 col-sm-12 col-xs-12">';
													if( $slide[(string) $i]['title'] ) {
														echo '<h2 class="slide-title animated '. $slide[(string) $i]['animate'] .'" style="color:'. $slide[(string) $i]['title_color'] .';">';
															echo $slide[(string) $i]['title'];
														echo '</h2>';
													}
													if( $button[(string) $i]['title'] ) {
														echo '<a href="'. $button[(string) $i]['url'] .'" class="button button-3d button-rounded button-xlarge animated '. $button[(string) $i]['animate'] .'">';
															echo $button[(string) $i]['title'];
														echo '</a>';
													}
												echo '</div>';
											echo '</div>';
										echo '</div>';
									echo '</div>';
								echo '</div>';
							echo '</div>';
						}
					}
				echo '</div>';
			echo '</div>';
		}
	}
}

/* Omit closing PHP tag to avoid "Headers already sent" issues. */

/**
 * 摜URL̃TCYႢURL擾
 * 
 * @param string $url 摜URL
 * @param string $size 摜̃TCY (thumbnail, medium, large or full)
 */ 
function get_attachment_image_src($url, $size) {
  $image = wp_get_attachment_image_src(get_attachment_id($url), $size);
  return $image[0];
}
/**
 * 摜URLattachemnt_id擾
 *
 * @param string $url 摜URL
 * @return int attachment_id
 */
function get_attachment_id($url)
{
  global $wpdb;
  $sql = "SELECT ID FROM {$wpdb->posts} WHERE post_name = %s";
  preg_match('/([^\/]+?)(-e\d+)?(-\d+x\d+)?(\.\w+)?$/', $url, $matches);
  $post_name = $matches[1];
  return (int)$wpdb->get_var($wpdb->prepare($sql, $post_name));
}